@@ -7,6 +7,16 @@
  */
  
  "use strict";
+
+ var { XPCOMUtils } = ChromeUtils.import("resource://gre/modules/XPCOMUtils.jsm");
+ 
+ XPCOMUtils.defineLazyModuleGetters(this, {
+  CalAlarm: "resource:///modules/CalAlarm.jsm",
+  CalAttachment: "resource:///modules/CalAttachment.jsm",
+  CalAttendee: "resource:///modules/CalAttendee.jsm",
+  CalEvent: "resource:///modules/CalEvent.jsm",
+  CalTodo: "resource:///modules/CalTodo.jsm",
+}); 
   
 var lightning = {
 
@@ -17,8 +27,9 @@ var lightning = {
     try {
       TbSync.lightning.cal = ChromeUtils.import("resource:///modules/calendar/calUtils.jsm").cal;
       TbSync.lightning.ICAL = ChromeUtils.import("resource:///modules/calendar/Ical.jsm").ICAL;
-      TbSync.lightning.cal.getCalendarManager().addCalendarObserver(this.calendarObserver);
-      TbSync.lightning.cal.getCalendarManager().addObserver(this.calendarManagerObserver);
+      let manager = TbSync.lightning.cal.manager;
+      manager.addCalendarObserver(this.calendarObserver);
+      manager.addObserver(this.calendarManagerObserver);
     } catch (e) {
       TbSync.dump("Check4Lightning","Error during lightning module import: " + e.toString() + "\n" + e.stack);
       Components.utils.reportError(e);
@@ -27,8 +38,9 @@ var lightning = {
 
   unload: async function () {
     //removing global observer
-    TbSync.lightning.cal.getCalendarManager().removeCalendarObserver(this.calendarObserver);
-    TbSync.lightning.cal.getCalendarManager().removeObserver(this.calendarManagerObserver);
+    let manager = TbSync.lightning.cal.manager;
+    manager.removeCalendarObserver(this.calendarObserver);
+    manager.removeObserver(this.calendarManagerObserver);
 
     //remove listeners on global sync buttons
     if (TbSync.window.document.getElementById("calendar-synchronize-button")) {
@@ -57,7 +69,7 @@ var lightning = {
     
     // Check, if the target exists and return true/false.
     hasTarget() {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let target = this._folderData.getFolderProperty("target");
       let calendar = calManager.getCalendarById(target);
       
@@ -69,7 +81,7 @@ var lightning = {
     // If the target does not exist, it should be created. Throw a simple Error, if that
     // failed.
     async getTarget() {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let target = this._folderData.getFolderProperty("target");
       let calendar = calManager.getCalendarById(target);
       
@@ -92,13 +104,13 @@ var lightning = {
      *
      */
     removeTarget() {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let target = this._folderData.getFolderProperty("target");
       let calendar = calManager.getCalendarById(target);
 
       try {
         if (calendar) {
-          TbSync.lightning.cal.getCalendarManager().removeCalendar(calendar);
+          calManager.removeCalendar(calendar);
         }
       } catch (e) {}
       TbSync.db.clearChangeLog(target);
@@ -113,7 +125,7 @@ var lightning = {
      * 
      */
     disconnectTarget() {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let target = this._folderData.getFolderProperty("target");
       let calendar = calManager.getCalendarById(target);
 
@@ -131,7 +143,7 @@ var lightning = {
     } 
     
     set targetName(newName) {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let target = this._folderData.getFolderProperty("target");
       let calendar = calManager.getCalendarById(target);
 
@@ -143,7 +155,7 @@ var lightning = {
     }
   
     get targetName() {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let target = this._folderData.getFolderProperty("target");
       let calendar = calManager.getCalendarById(target);
 
@@ -214,7 +226,7 @@ var lightning = {
     // replace this with your own implementation to create the actual addressbook,
     // when this class is extended
     async createCalendar(newname) {
-      let calManager = TbSync.lightning.cal.getCalendarManager();
+      let calManager = TbSync.lightning.cal.manager;
       let newCalendar = calManager.createCalendar("storage", Services.io.newURI("moz-storage-calendar://"));
       newCalendar.id = TbSync.lightning.cal.getUUID();
       newCalendar.name = newname;
@@ -328,7 +340,6 @@ var lightning = {
   TbCalendar : class {
     constructor(calendar, folderData) {
       this._calendar = calendar;
-      this._promisifyCalendar = TbSync.lightning.cal.async.promisifyCalendar(this._calendar.wrappedJSObject);
       this._folderData = folderData;
      }
 
@@ -337,7 +348,7 @@ var lightning = {
     }
     
     get promisifyCalendar() {
-      return this._promisifyCalendar;
+      return this._calendar;
     }
 
     get logUserChanges() {
@@ -355,12 +366,12 @@ var lightning = {
     }
 
     createNewEvent() {
-      let event = TbSync.lightning.cal.createEvent();
+      let event = new CalEvent();
       return new TbSync.lightning.TbItem(this, event);
     }
     
     createNewTodo() {
-      let todo = TbSync.lightning.cal.createTodo();
+      let todo = new CalTodo();
       return new TbSync.lightning.TbItem(this, todo);
     }
 
@@ -376,7 +387,7 @@ var lightning = {
       if (pretagChangelogWithByServerEntry) {
         tbItem.changelogStatus = "added_by_server";
       }
-      return await this._promisifyCalendar.adoptItem(tbItem._item);
+      return await this._calendar.adoptItem(tbItem._item);
     }
     
     async modifyItem(tbNewItem, tbOldItem, pretagChangelogWithByServerEntry = true) {
@@ -386,21 +397,22 @@ var lightning = {
         tbNewItem.changelogStatus = "modified_by_server";
       }
       
-      return await this._promisifyCalendar.modifyItem(tbNewItem._item, tbOldItem._item); 
+      return await this._calendar.modifyItem(tbNewItem._item, tbOldItem._item); 
     }        
     
     async deleteItem(tbItem, pretagChangelogWithByServerEntry = true) {
       if (pretagChangelogWithByServerEntry) {
         tbItem.changelogStatus = "deleted_by_server";
       }
-      return await this._promisifyCalendar.deleteItem(tbItem._item); 
+      return await this._calendar.deleteItem(tbItem._item); 
     }
     
     // searchId is interpreted as the primaryKeyField, which is the UID for this target
     async getItem (searchId) {
-      let item = await this._promisifyCalendar.getItem(searchId); 
-      if (item.length == 1) return new TbSync.lightning.TbItem(this, item[0]);
-      if (item.length > 1) throw "Oops: getItem returned <"+item.length+"> elements!";
+      let item = await this._calendar.getItem(searchId); 
+      if (item) {
+        return new TbSync.lightning.TbItem(this, item);
+      }
       return null;
     }
 
@@ -409,13 +421,9 @@ var lightning = {
       else throw ("TbSync.lightning.getItemFromProperty: Currently onle the UID property can be used to search for items.");
     }
 
-    async getAllItems () {
-      return await this._promisifyCalendar.getAllItems(); 
+    async getAllItems() {
+      return await this._calendar.getItems(Ci.calICalendar.ITEM_FILTER_ALL_ITEMS, 0, null, null);
     }
-      
-  
-  
-  
   
     getAddedItemsFromChangeLog(maxitems = 0) {             
       return TbSync.db.getItemsFromChangeLog(this.calendar.id, maxitems, "added_by_user").map(item => item.itemId);
@@ -660,7 +668,7 @@ var lightning = {
         // we wait a bit and check, if the calendar is back again and ignore the delete event.
         if (aCalendar.type == "caldav") {
           await TbSync.tools.sleep(1500);
-          let calManager = TbSync.lightning.cal.getCalendarManager();          
+          let calManager = TbSync.lightning.cal.manager;
           for (let calendar of calManager.getCalendars({})) {
             if (calendar.uri.spec == aCalendar.uri.spec) {
               // update the target
@@ -693,7 +701,7 @@ var lightning = {
   
   //this function actually creates a calendar if missing
   prepareAndCreateCalendar: async function (folderData) {       
-    let calManager = TbSync.lightning.cal.getCalendarManager();
+    let calManager = TbSync.lightning.cal.manager;
     let provider = folderData.accountData.getAccountProperty("provider");
 
     //check if  there is a known/cached name, and use that as starting point to generate unique name for new calendar 
